@@ -10,10 +10,17 @@ fn rerun_if_changed(path_str: &str) -> bool {
         || path.starts_with("docs")
         || path.starts_with("test")
         || path.starts_with(".github")
+        || path.ends_with("tests.rs")
     {
         return false;
     }
 
+    for ancestor in path.ancestors() {
+        if ancestor.ends_with("tests") {
+            return false;
+        }
+    }
+
     !matches!(
         path_str,
         "COPYING" | "Makefile" | "clippy.toml" | "rustfmt.toml" | "rust-toolchain"
@@ -39,14 +46,26 @@ fn main() {
         );
 
         println!("cargo:rerun-if-changed=build.rs");
-        println!("cargo:rerun-if-changed=.git/HEAD");
 
-        let head = std::fs::read_to_string(".git/HEAD").unwrap_or_default();
-        if head.starts_with("ref: ") {
-            let path_str = format!(".git/{}", head[5..].trim());
-            let path = Path::new(&path_str);
-            if path.exists() {
-                println!("cargo:rerun-if-changed={}", path_str);
+        let git_head = std::process::Command::new("git")
+            .args(&["rev-parse", "--git-dir"])
+            .output()
+            .ok()
+            .and_then(|r| String::from_utf8(r.stdout).ok())
+            .and_then(|s| s.lines().next().map(ToOwned::to_owned))
+            .map(|ref s| Path::new(s).to_path_buf())
+            .unwrap_or_else(|| Path::new(".git").to_path_buf())
+            .join("HEAD");
+        if git_head.exists() {
+            println!("cargo:rerun-if-changed={}", git_head.display());
+
+            let head = std::fs::read_to_string(&git_head).unwrap_or_default();
+            if head.starts_with("ref: ") {
+                let path_str = format!(".git/{}", head[5..].trim());
+                let path = Path::new(&path_str);
+                if path.exists() {
+                    println!("cargo:rerun-if-changed={}", path_str);
+                }
             }
         }
     }
